<?php
// Specify the directory where uploaded images will be stored
$target_dir = "uploads/";
// Specify the path of the text file where URLs will be saved
$text_file = "data/image_urls.txt";
// The secondary text file to save API responses
$apiResponseFile = "data/api_responses.txt";
// Paths for MOOD and VOICE values
$moodFile = "data/mood_value.txt";
$voiceFile = "data/voice_value.txt";
// The full path to the uploaded file
$target_file = $target_dir . basename($_FILES["fileToUpload"]["name"]);
// URL to access the uploaded image
$serverUrl = 'https://YOURURL/TheWeatherChannel/' . $target_file;
// Maximum file size (5MB)
$maxFileSize = 5 * 1024 * 1024; // 5 MB in bytes

function getLastImageUrl($filePath) {
    $lines = file($filePath, FILE_IGNORE_NEW_LINES | FILE_SKIP_EMPTY_LINES);
    if ($lines && is_array($lines)) {
        $lastLine = trim(end($lines));
        if (false !== $urlPart = strrpos($lastLine, "URL: ")) {
            return substr($lastLine, $urlPart + 5);
        }
    }
    return false;
}

function getLastVoiceValue($filePath) {
    $lines = file($filePath, FILE_IGNORE_NEW_LINES | FILE_SKIP_EMPTY_LINES);
    if ($lines && is_array($lines)) {
        $lastLine = trim(end($lines));
        return substr($lastLine, strpos($lastLine, "Voice: ") + 7);
    }
    return 'DEFAULT-VOICE-ID';
}

function getLastMoodValue($filePath) {
    $lines = file($filePath, FILE_IGNORE_NEW_LINES | FILE_SKIP_EMPTY_LINES);
    if ($lines && is_array($lines)) {
        $lastLine = trim(end($lines));
        return substr($lastLine, strpos($lastLine, "Mood: ") + 6);
    }
    return 'DEFAULT-MOOD';
}

if (isset($_POST["submit"])) {
    $imageDescription = htmlspecialchars($_POST['imageDescription']);
    $mood = htmlspecialchars($_POST['mood']);
    $voice = htmlspecialchars($_POST['voice']);

    file_put_contents($moodFile, "Mood: " . $mood . PHP_EOL, LOCK_EX);
    file_put_contents($voiceFile, "Voice: " . $voice . PHP_EOL, LOCK_EX);

    if ($_FILES["fileToUpload"]["size"] > $maxFileSize) {
        echo "<p>Sorry, your file is too large. Maximum file size is 5 MB.</p>";
    } else {
        if (move_uploaded_file($_FILES["fileToUpload"]["tmp_name"], $target_file)) {
            echo "<p>The file " . htmlspecialchars(basename($_FILES["fileToUpload"]["name"])) . " has been uploaded.</p>";

            $textToSave = "Description: $imageDescription, URL: $serverUrl";
            file_put_contents($text_file, $textToSave . PHP_EOL, FILE_APPEND | LOCK_EX);

            $lastImageUrl = getLastImageUrl($text_file);
            $lastVoiceId = getLastVoiceValue($voiceFile);
            $lastMoodValue = getLastMoodValue($moodFile);

            $curl = curl_init();
            curl_setopt_array($curl, array(
                CURLOPT_URL => 'https://api.d-id.com/talks',
                CURLOPT_RETURNTRANSFER => true,
                CURLOPT_ENCODING => '',
                CURLOPT_MAXREDIRS => 10,
                CURLOPT_TIMEOUT => 0,
                CURLOPT_FOLLOWLOCATION => true,
                CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
                CURLOPT_CUSTOMREQUEST => 'POST',
                CURLOPT_POSTFIELDS => json_encode([
                    "script" => [
                        "type" => "text",
                        "input" => $imageDescription,
                        "provider" => [
                            "type" => "microsoft",
                            "voice_id" => $lastVoiceId
                        ],
                        "config" => [
                            "driver_expressions" => [
                                "expressions" => [
                                    [
                                        "start_frame" => 0,
                                        "expression" => $lastMoodValue,
                                        "intensity" => 1
                                    ]
                                ]
                            ]
                        ]
                    ],
                    "source_url" => $lastImageUrl
                ]),
                CURLOPT_HTTPHEADER => array(
                    'Content-Type: application/json',
                    'Authorization: Basic APIKEYHERE'
                ),
            ));

            $response = curl_exec($curl);

                       if (curl_errno($curl)) {
                echo "<p>Error:" . curl_error($curl) . "</p>";
            } else {
                echo "<p>API Response: " . htmlspecialchars($response) . "</p>";
                file_put_contents($apiResponseFile, $response . PHP_EOL, FILE_APPEND | LOCK_EX);
            }

            curl_close($curl);

        } else {
            echo "<p>Sorry, there was an error uploading your file.</p>";
        }
    }
}

    echo "<p>Image Description: " . $imageDescription . "</p>";
    echo "<p>Source URL: " . $lastImageUrl . "</p>";
    echo "<p>Voice ID: " . $lastVoiceId . "</p>";
    echo "<p>Mood: " . $lastMoodValue . "</p>";
?>


